Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(54)

Unified Diff: components/offline_pages/core/offline_page_archiver.h

Issue 2656713002: Merge to M57: Remove popup overlay from MHTML when requested (Closed)
Patch Set: Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/offline_pages/core/offline_page_archiver.h
diff --git a/components/offline_pages/core/offline_page_archiver.h b/components/offline_pages/core/offline_page_archiver.h
index c224ef958e4ffeee55ac73d4cb6f59560d785856..17631406db34fd76b9b2895dd1a5779a9fdb7db4 100644
--- a/components/offline_pages/core/offline_page_archiver.h
+++ b/components/offline_pages/core/offline_page_archiver.h
@@ -58,6 +58,14 @@ class OfflinePageArchiver {
// there was a security error.
};
+ // Describes the parameters to control how to create an archive.
+ struct CreateArchiveParams {
+ CreateArchiveParams() : remove_popup_overlay(false) {}
+
+ // Whether to remove popup overlay that obstructs viewing normal content.
+ bool remove_popup_overlay;
+ };
+
typedef base::Callback<void(OfflinePageArchiver* /* archiver */,
ArchiverResult /* result */,
const GURL& /* url */,
@@ -68,11 +76,11 @@ class OfflinePageArchiver {
virtual ~OfflinePageArchiver() {}
// Starts creating the archive in the |archives_dir| with |archive_id| added
// to the archive filename. Once archive is created |callback| will be called
// with the result and additional information.
virtual void CreateArchive(const base::FilePath& archives_dir,
- int64_t archive_id,
+ const CreateArchiveParams& create_archive_params,
const CreateArchiveCallback& callback) = 0;
};
« no previous file with comments | « chrome/browser/android/offline_pages/recent_tab_helper.cc ('k') | components/offline_pages/core/offline_page_client_policy.h » ('j') | no next file with comments »
@@ -68,11 +76,11 @@ class OfflinePageArchiver {
virtual ~OfflinePageArchiver() {}
- // Starts creating the archive in the |archives_dir| with |archive_id| added
- // to the archive filename. Once archive is created |callback| will be called
+ // Starts creating the archive in the |archives_dir| per
+ // |create_archive_params|. Once archive is created |callback| will be called
// with the result and additional information.
virtual void CreateArchive(const base::FilePath& archives_dir,

Powered by Google App Engine
This is Rietveld 408576698